@@ -10,16 +10,37 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QDBusMessage>
 #include <QObject>
 
+#include <expected>
+
 class QDBusServiceWatcher;
 
 namespace ScreenLocker
 {
+
+class PowerInhibitor : public QObject
+{
+    Q_OBJECT
+
+public:
+    PowerInhibitor(const QString &applicationName, const QString &reason);
+    void release();
+
+private:
+    ~PowerInhibitor() override;
+
+    void inhibit(const QString &applicationName, const QString &reason);
+    void uninhibit();
+
+    std::optional<std::expected<uint, QDBusError>> m_cookie;
+    bool m_released = false;
+};
+
 class InhibitRequest
 {
 public:
     QString dbusid;
     uint cookie;
-    uint powerdevilcookie;
+    PowerInhibitor *powerInhibitor = nullptr;
 };
 
 class KSldApp;
